const path = require('path');
const Dotenv = require('dotenv-webpack');
const build_env = process.env.build_env ? process.env.build_env : 'dev';
module.exports = context => {
  const { webpack } = context;

  return {
    mode: process.env.NODE_ENV,
    devtool: 'source-map',
    entry: {
      index: './src/index.js'
    },
    resolve: {
      alias: {
        '@': path.resolve(__dirname, './src')
      }
    },
    plugins: [
      new Dotenv({
        path: `.env.${build_env}`, // load this now instead of the ones in '.env'
        safe: false, // load '.env.example' to verify the '.env' variables are all set. Can also be a string to a different file.
        systemvars: true, // load all the predefined 'process.env' variables which will trump anything local per dotenv specs.
        silent: false // hide any errors
      })
    ],
    output: {
      path: path.resolve('release'),
      filename: process.env.NODE_ENV === 'development' ? '[name].js' : '[name].[contenthash].js'
    },
    optimization: {
      splitChunks: {
        chunks: 'all'
      }
    }
  };
};
